from qtrf.numeric_suffix import prefix_map

# prefixes
prefix_map = prefix_map.copy()
del(prefix_map['M'])
del(prefix_map['G'])
del(prefix_map['T'])

# units
units = 'V'
